@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.09';
+our $VERSION = '1.10';
 
 use Carp;
 use Exporter;
@@ -51,7 +51,7 @@ sub read {
 
         if (! $testing){
             for (@contents){
-                s/(?:\n|\x{0B}|\f|\r|\x{85}){1,2}//;
+                s/[\n\x{0B}\f\r\x{85}]{1,2}//;
             }
         }
         return @contents;
@@ -76,11 +76,11 @@ sub write {
     }
 
     $file = $copy if $copy;
-
+    
     if (! $self->{is_read}){
         $self->recsep($file);
     }
-
+    
     my $wfh = $self->_open($file, 'w');
 
     $recsep = defined $recsep ? $recsep : $self->{recsep};
@@ -91,14 +91,14 @@ sub write {
         seek $contents, 0, 0;
 
         while (<$contents>){
-            s/(?:\n|\x{0B}|\f|\r|\x{85}){1,2}//g;
+            s/[\n\x{0B}\f\r\x{85}]{1,2}//g;
             print $wfh $_ . $recsep;
         }
         close $contents;
     }
     else {
         for (@$contents){
-            s/(?:\n|\x{0B}|\f|\r|\x{85}){1,2}//g;
+            s/[\n\x{0B}\f\r\x{85}]{1,2}//g;
             print $wfh $_ . $recsep;
         }
     }
@@ -202,8 +202,6 @@ sub recsep {
         $fh = $self->_open($file);
     };
 
-    croak "recsep() couldn't acquire file handle for $file" if $@;
-
     my $recsep;
 
     if ($@ || ! <$fh>){
@@ -225,7 +223,8 @@ sub recsep {
     }
 
     seek $fh, 0, 0;
-    if (<$fh> =~ /((?:\n|\x{0B}|\f|\r|\x{85}){1,2})/){
+
+    if (<$fh> =~ /([\n\x{0B}\f\r\x{85}]{1,2})/){
         $self->{recsep} = $1;
     }
 
@@ -265,7 +264,7 @@ sub platform_recsep {
 
     my $fh = $self->_open($file);
 
-    if (<$fh> =~ /((?:\n|\x{0B}|\f|\r|\x{85}){1,2})/){
+    if (<$fh> =~ /([\n\x{0B}\f\r\x{85}]{1,2})/){
         $self->{platform_recsep} = $1;
     }
 
@@ -332,7 +331,7 @@ sub _handle {
         my $platform_recsep = $self->platform_recsep;
 
         while (<$fh>){
-            s/(?:\n|\x{0B}|\f|\r|\x{85}){1,2}/$platform_recsep/g;
+            s/[\n\x{0B}\f\r\x{85}]{1,2}/$platform_recsep/g;
             print $temp_wfh $_;
         }
         
